<div align="center">
  Poker Engine
  <br />
  <a href="https://github.com/pokerlost/pokerengine/issues/new?assignees=&labels=bug&template=01_BUG_REPORT.md&title=bug%3A+">Report a Bug</a>
  ·
  <a href="https://github.com/pokerlost/pokerengine/issues/new?assignees=&labels=enhancement&template=02_FEATURE_REQUEST.md&title=feat%3A+">Request a Feature</a>
  .
  <a href="https://github.com/pokerlost/pokerengine/issues/new?assignees=&labels=question&template=04_SUPPORT_QUESTION.md&title=support%3A+">Ask a Question</a>
</div>

<div align="center">
<br />

[![Project license](https://img.shields.io/github/license/pokerlost/pokerengine.svg?style=flat-square)](LICENSE)

[![Pull Requests welcome](https://img.shields.io/badge/PRs-welcome-ff69b4.svg?style=flat-square)](https://github.com/pokerlost/pokerengine/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)
[![code with love by pokerlost](https://img.shields.io/badge/%3C%2F%3E%20with%20%E2%99%A5%20by-pokerlost-ff1414.svg?style=flat-square)](https://github.com/pokerlost)

</div>

<details open="open">
<summary>Table of Contents</summary>

- [About](#about)
    - [Built With](#built-with)
- [Getting Started](#getting-started)
    - [Prerequisites](#prerequisites)
    - [Installation](#installation)
- [Usage](#usage)
- [Support](#support)
- [Contributing](#contributing)
- [Authors & contributors](#authors--contributors)
- [License](#license)

</details>

---

## About

> A Texas Hold'em variant poker engine that allows you to calculate hand combinations separately from the game, create
> rooms and manage the game.
> The first of its kind Python engine that enables the entire process of playing Texas Hold'em Poker.

### Built With

> C++ pybind11 magic_enum Python pydantic scikit-build-core black isort ruff mypy build

## Getting Started

### Prerequisites

> g++11 cmake python3.1*

### Installation

To install project follow:

```shell
git clone https://github.com/pokerlost/pokerengine && cd pokerengine
python -m venv venv
source venv/bin/activate
python -m build .
pip install .
```

## Usage

The usage examples currently stores at `examples`.

## Support

Reach out to the maintainer at one of the following places:

- [GitHub issues](https://github.com/pokerlost/pokerengine/issues/new?assignees=&labels=question&template=04_SUPPORT_QUESTION.md&title=support%3A+)
- Contact options listed on [this GitHub profile](https://github.com/pokerlost)
- Contact with [Telegram](https://mlosu.t.me)

## Contributing

First off, thanks for taking the time to contribute! Contributions are what make the open-source community such an
amazing place to learn, inspire, and create. Any contributions you make will benefit everybody else and are **greatly
appreciated**.

Please read [our contribution guidelines](docs/CONTRIBUTING.md), and thank you for being involved!

## Authors & contributors

The original setup of this repository is by [pokerlost](https://github.com/pokerlost).

For a full list of all authors and contributors,
see [the contributors page](https://github.com/pokerlost/pokerengine/contributors).

## License

This project is licensed under the **MIT license**.

See [LICENSE](LICENSE) for more information.
